local f = CreateFrame("Frame")

local defaults = {
    hideRealm = true,
	hideName = false,
    hideRole = false,
	hideRaidMan = false,
	hideNameArena = true,
}

function f:OnEvent(event, addOnName)
	if addOnName == "HideRealmNames" then
		HideRealmNamesDB = HideRealmNamesDB or CopyTable(defaults)
		self.db = HideRealmNamesDB
		self:InitializeOptions()

		--Hide players realm on raid frame
		if self.db.hideRealm then
			hooksecurefunc("CompactUnitFrame_UpdateName",function(frame)
				if frame and not frame:IsForbidden() then
					local frame_name = frame:GetName()
				if frame_name and frame_name:match("^PartyMemberFrame%d") or ("^CompactRaidFrame%d") or ("^CompactRaidGroup%dMember%d") or ("^CompactPartyFrameMember%d") and frame.unit and frame.name then
					local unit_name = GetUnitName(frame.unit,true)
				if unit_name then
					frame.name:SetText(unit_name:match("[^-]+"))
				end end end
			end)
		end

		--Hide player names on raid frame
		if self.db.hideName then
			DefaultCompactUnitFrameOptions.displayName = false
		end

		--Hide role icons on raid frame
		if self.db.hideRole then
			DefaultCompactUnitFrameOptions.displayRoleIcon = false
		end

		--Hide Raid Manager Panel
		if self.db.hideRaidMan then
			if select(4,GetBuildInfo())>=100002 then --Retail
				CompactRaidFrameManager:HookScript("OnShow", function(s) s:Hide() end)
				CompactRaidFrameManager:Hide()
			else --Classic
				CompactRaidFrameContainer:SetParent(UIParent)
				CompactRaidFrameManager:HookScript("OnShow", function(s) s:Hide() end)
				CompactRaidFrameManager:Hide()
			end
		end

		--Replace enemy player names with numbers on arena namplates
		if self.db.hideNameArena then
			local U=UnitIsUnit hooksecurefunc("CompactUnitFrame_UpdateName",function(F)if IsActiveBattlefieldArena()and F.unit:find("nameplate")then for i=1,5 do if U(F.unit,"arena"..i)then F.name:SetText(i)F.name:SetTextColor(1,0,0)break end end end end)
			local U=UnitIsUnit hooksecurefunc("CompactUnitFrame_UpdateName",function(F)if F.unit:find("nameplate")then for i=1,5 do if U(F.unit,"party"..i)then F.name:SetText(i)F.name:SetTextColor(0,1,0)break end end end end)
		end

	end
end

f:RegisterEvent("ADDON_LOADED")
f:SetScript("OnEvent", f.OnEvent)

function f:InitializeOptions()
	self.panel = CreateFrame("Frame")
	self.panel.name = "Hide Realm Names"

	local title = self.panel:CreateFontString(nil, "ARTWORK", "GameFontNormalLarge")
	title:SetPoint("TOPLEFT", 16, -16)
	title:SetText(self.panel.name)

	local subtitle = self.panel:CreateFontString(nil, 'ARTWORK', 'GameFontHighlight')
	subtitle:SetJustifyH('LEFT')
	subtitle:SetPoint('TOPLEFT', title, 'BOTTOMLEFT', 0, -8)
	subtitle:SetPoint('RIGHT', -32, 0)
	subtitle:SetText('All changes will take effect after a UI reload.')

	local subheader_1 = self.panel:CreateFontString(nil, 'ARTWORK', 'GameFontNormal')
	subheader_1:SetJustifyH('LEFT')
	subheader_1:SetPoint('TOPLEFT', subtitle, 'BOTTOMLEFT', 0, -20)
	subheader_1:SetPoint('RIGHT', -32, 0)
	subheader_1:SetText('--- Raid Frame Options ---')
    
    local cb_hide_realms = CreateFrame("CheckButton", nil, self.panel, "InterfaceOptionsCheckButtonTemplate")
	cb_hide_realms:SetPoint("TOPLEFT", subheader_1, 0, -25)
	cb_hide_realms.Text:SetText("Hide Realm Names")
	cb_hide_realms:HookScript("OnClick", function(_, btn, down)
		self.db.hideRealm = cb_hide_realms:GetChecked()
	end)
	cb_hide_realms:SetChecked(self.db.hideRealm)

	local cb_hide_names = CreateFrame("CheckButton", nil, self.panel, "InterfaceOptionsCheckButtonTemplate")
	cb_hide_names:SetPoint("TOPLEFT", cb_hide_realms, 0, -30)
	cb_hide_names.Text:SetText("Hide Player Names")
	cb_hide_names:HookScript("OnClick", function(_, btn, down)
		self.db.hideName = cb_hide_names:GetChecked()
	end)
	cb_hide_names:SetChecked(self.db.hideName)

    local cb_hide_roles = CreateFrame("CheckButton", nil, self.panel, "InterfaceOptionsCheckButtonTemplate")
	cb_hide_roles:SetPoint("TOPLEFT", cb_hide_names, 0, -30)
	cb_hide_roles.Text:SetText("Hide Role Icons")
	cb_hide_roles:HookScript("OnClick", function(_, btn, down)
		self.db.hideRole = cb_hide_roles:GetChecked()
	end)
	cb_hide_roles:SetChecked(self.db.hideRole)

	local cb_hide_raidman = CreateFrame("CheckButton", nil, self.panel, "InterfaceOptionsCheckButtonTemplate")
	cb_hide_raidman:SetPoint("TOPLEFT", cb_hide_roles, 0, -30)
	cb_hide_raidman.Text:SetText("Hide Raid Frame Manager (left side panel)")
	cb_hide_raidman:HookScript("OnClick", function(_, btn, down)
		self.db.hideRaidMan = cb_hide_raidman:GetChecked()
	end)
	cb_hide_raidman:SetChecked(self.db.hideRaidMan)

	local subheader_2 = self.panel:CreateFontString(nil, 'ARTWORK', 'GameFontNormal')
	subheader_2:SetJustifyH('LEFT')
	subheader_2:SetPoint('TOPLEFT', cb_hide_raidman, 'BOTTOMLEFT', 0, -35)
	subheader_2:SetPoint('RIGHT', -32, 0)
	subheader_2:SetText('--- Miscellaneous Options ---')

	local cb_hide_arena = CreateFrame("CheckButton", nil, self.panel, "InterfaceOptionsCheckButtonTemplate")
	cb_hide_arena:SetPoint("TOPLEFT", subheader_2, 0, -30)
	cb_hide_arena.Text:SetText("Replace Enemy Names with Numbers on Arena Nameplates")
	cb_hide_arena:HookScript("OnClick", function(_, btn, down)
		self.db.hideNameArena = cb_hide_arena:GetChecked()
	end)
	cb_hide_arena:SetChecked(self.db.hideNameArena)

	local btn = CreateFrame("Button", nil, self.panel, "UIPanelButtonTemplate")
	btn:SetPoint("TOPLEFT", cb_hide_arena, 0, -50)
	btn:SetText("Save and Reload")
	btn:SetWidth(126)
	btn:SetScript("OnClick", function()
        ReloadUI();
	end)

	InterfaceOptions_AddCategory(self.panel)
end

SLASH_HRN1 = "/hrn"
SLASH_HRN2 = "/hiderealmnames"

SlashCmdList.HRN = function(msg, editBox)
	InterfaceOptionsFrame_OpenToCategory(f.panel)
end